﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Xml;

namespace Prevodnik_jednotiek
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        XML xml;
        Converts converts;
        public MainWindow()
        {

            InitializeComponent();
            xml = XML.Instance();
            converts = Converts.Instance();
            initializeSystemLanguage();
        }


        /// <summary>
        /// Funkcia nam nainicializuje systemovy jazyk uzivatela a priradi ako default
        /// </summary>
        private void initializeSystemLanguage()
        {
            /*Ziskame jazyk systemu*/
            CultureInfo info = CultureInfo.InstalledUICulture;
            string language = info.TwoLetterISOLanguageName;
            /*list jazykov*/
            List<string> languages = new List<string>() { "cs","en","sk"};
            ComboLanguage.ItemsSource = languages;
            int count = 0;
            foreach(string item in languages)
            {
                if (item == language)
                {
                    ComboLanguage.SelectedValue = item;
                }
                else if (count == languages.Count)
                {
                    MessageBox.Show("Prepáčte ale Vami zvolený systémový jazyk nie je podporovaný!");
                }
                else 
                    count++;
                
            }
            
            
        }

        /// <summary>
        /// Funkcia nam ziska hodnoty pre konkretny jazyk a nacita ich do popiskov
        /// </summary>
        /// <param name="language"></param>
        private void languagesData(string language)
        {
            List<String> data = xml.getDataForLanguage(language);
            
            //Pridelime jednotlive hodnoty textovym polom
            TextUnitConverter.Content = data.ElementAt(0);
            TextCategory.Content = data.ElementAt(1);
            TextSelectLanguage.Content = data.ElementAt(2);
            TextConvertFrom.Content = data.ElementAt(3);
            TextConvertTo.Content = data.ElementAt(4);
            ComboCategory.ItemsSource = new List<string>() { data.ElementAt(5), data.ElementAt(6), data.ElementAt(7) };
            ComboCategory.SelectedIndex = 0;
        }

        private void ComboLanguage_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            string language = ComboLanguage.SelectedItem.ToString();
            languagesData(language);
        }

        /// <summary>
        /// Funkcia nam ziska jednotky pre kategoriu a nacita ich do comboBoxoch
        /// </summary>
        /// 

        private void unitsData(string language)
        {
            string category = "";
            // nastavujeme index, podmienka kvoli znovunacitani pri kategorii, vracia -1
            int index = (ComboCategory.SelectedIndex == -1)? 0 : ComboCategory.SelectedIndex;
            switch(index)
            {
                case 0:
                    category = "measure";
                    break;
                case 1:
                    category = "weight";
                    break;
                case 2:
                    category = "dataCapacity";
                    break;
                default:
                    break;
            }
            List<string> data = xml.getDataForUnits(category);

            //Nacitame jednotky konkretnej kategorie
            ComboConvertFrom.ItemsSource = data;
            ComboConvertTo.ItemsSource = data;

            // Nastavime zobrazovanie prvej polozky
            ComboConvertFrom.SelectedIndex = 0;
            ComboConvertTo.SelectedIndex = 0;
        }

        private void ComboCategory_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            string language = ComboLanguage.SelectedItem.ToString();
            BoxFrom.Text = "";
            BoxTo.Text = "";
            unitsData(language);
        }

        private void BoxFrom_TextChanged(object sender, TextChangedEventArgs e)
        {

            controlTextBox();
            
        }

        private void controlTextBox()
        {
            double firstValue;
            double result = 0;
            /*Ak davame spravne cislo*/
            if (double.TryParse(BoxFrom.Text, out firstValue))
            {
                string firstType = ComboConvertFrom.SelectedValue.ToString();
                string secondType = ComboConvertTo.SelectedValue.ToString();
                //VYPOCTY
                switch(ComboCategory.SelectedIndex)
                {
                    case 0:
                        result = converts.getMeasureValue(firstValue,firstType,secondType);
                        break;
                    case 1:
                        result = converts.getWeightValue(firstValue, firstType, secondType);
                        break;
                    case 2:
                        result = converts.getDataCapacityValue(firstValue, firstType, secondType);
                        break;
                    default:
                        break;

                }
                BoxTo.Text = result.ToString();

            }
                /*Ak nemame nic vo from, tak ani v TO*/
            else if (BoxFrom.Text == "")
            {
                BoxTo.Text = "";
            }
                /*Ak davame ako vstup string, tak nic neukazuj*/
            else
            {
                BoxFrom.Text = "";
            }
        }

        private void ComboConvertFrom_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            controlTextBox();
        }

        private void ComboConvertTo_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            controlTextBox();
        }

        
        

        

        


        


        

        

       
        
    }
}
